(function (document, Drupal) {

  'use strict';

  /*
    Adding 'aria-describedby' attribute to invalid form input elements
    with error message class 'form-item--error-message'.
    And identify the errors using ARIA live regions 'role=alert'.
   */

  Drupal.forma11y = {};

  Drupal.forma11y.findItemParent = function(el) {
    if (el.classList.contains('js-form-item')) {
      return el;
    }

    if (el.classList.contains('js-form-wrapper') || el.parentNode === null) {
      return false;
    }

    return Drupal.forma11y.findItemParent(el.parentNode);
  };

  Drupal.behaviors.forma11y = {
    attach: function (context) {
      var errorMessages = context.querySelectorAll('.form-item--error-message');

      if (errorMessages.length > 0) {
        for (var i = 0; i < errorMessages.length; i++) {
          var errorItem = Drupal.forma11y.findItemParent(errorMessages[i]);

          if (errorItem) {
            var errorInput = errorItem.querySelector('[aria-invalid="true"]');
            var errorMessageId = errorInput.id.concat('-error-message');

            errorMessages[i].setAttribute('role', 'alert');
            errorMessages[i].setAttribute('id', errorMessageId);
            errorInput.classList.add('is-forma11y');
            errorInput.setAttribute('aria-describedby', errorMessageId);
          }
        }
      }
    }
  };

})(document, Drupal);
